*django-geoexplorer* allows you to use `GeoExplorer <http://opengeo.org>`_
in your `Django <https://www.djangoproject.com>`_ projects.

This is just packaging work for the great opengeo suite client sdk.

The releases will be done based on the suite releases or a git hash will be appended to the package name before publishing to pypi in the following way:

3.0.1.devXXXXX where XXXXX is the git hash and the url to the source code can be constructed as follows:

https://github.com/opengeo/suite/tree/XXXXX

=======
INSTALL
=======

::

    pip install django-geoexplorer

=====
USAGE
=====

* Add ``geoexplorer`` to your ``INSTALLED_APPS``


=======
AUTHORS
=======

* Ariel Núñez <http://ingenieroariel.com>

=======
LICENSE
=======

* Lesser GNU Public License
* OpenGeo Suite License - GPL
